/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef TAXADJUSTMENT_H
#define TAXADJUSTMENT_H

#include "guiclient.h"
#include "xdialog.h"
#include <parameter.h>
#include "ui_taxAdjustment.h"

class taxAdjustment : public XDialog, public Ui::taxAdjustment
{
    Q_OBJECT

public:
    taxAdjustment(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
    ~taxAdjustment();

public slots:
    virtual enum SetResponse set( const ParameterList & pParams );
    virtual void sSave();
    virtual void sCheck();

protected slots:
    virtual void languageChange();

private:
  int _sense;
  int _taxhistid;
  int _mode;
  int _orderid;
  QString _table;
	
};

#endif // TAXADJUSTMENT
